﻿/*
 * Copyright (c) 2015 Razeware LLC
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

using UnityEngine;
using System.Collections;

public class EnemyProducer : MonoBehaviour {

  public bool shouldSpawn;
  public Enemy[] enemyPrefabs;
  public float[] moveSpeedRange;
  public int[] healthRange;

  Bounds spawnArea;
  GameObject player;

	void Start () {
    spawnArea = this.GetComponent<BoxCollider>().bounds;
    SpawnEnemies(shouldSpawn);
    InvokeRepeating("spawnEnemy", 0.5f, 1.0f);
	}

  public void SpawnEnemies(bool shouldSpawn) {
    if(shouldSpawn) {
      player = GameObject.FindGameObjectWithTag("Player");
    }
    this.shouldSpawn = shouldSpawn;
  }

  void spawnEnemy() {
    if(shouldSpawn == false || player == null) {
      return;
    }

    int index = Random.Range(0, enemyPrefabs.Length);
    var newEnemy = Instantiate(enemyPrefabs[index], randomSpawnPosition(), Quaternion.identity) as Enemy;
    newEnemy.Initialize(player.transform, 
        Random.Range(moveSpeedRange[0], moveSpeedRange[1]), 
        Random.Range(healthRange[0], healthRange[1]));
  }

  Vector3 randomSpawnPosition() {
    float x = Random.Range(spawnArea.min.x, spawnArea.max.x);
    float z = Random.Range(spawnArea.min.z, spawnArea.max.z);
    float y = 0.5f;

    return new Vector3(x, y, z);
  }


}
